@@ -24,6 +24,9 @@ class IHubSensors:
     chargerobject: ChargerObject = field(init=False)
     chargerobject_switch: ChargerSwitch = field(init=False)
     state_machine: Any = field(init=False)
+    powersensormovingaverage: HubMember = field(init=False)
+    powersensormovingaverage24: HubMember = field(init=False)
+    power: Power = field(init=False)
 
     @abstractmethod
     def setup(self):
@@ -59,11 +62,14 @@ class IHubSensors:
             initval=0,
             startpeaks=options.startpeaks,
         )
-        self.chargerobject = ChargerObject(
-            data_type=self.chargertype.charger.native_chargerstates,
-            listenerentity=self.chargertype.charger.entities.chargerentity
-        )
-        resultdict[self.chargerobject.entity] = self.chargerobject.is_initialized
+        if len(self.chargertype.charger.entities.chargerentity) > 0:
+            self.chargerobject = ChargerObject(
+                data_type=self.chargertype.charger.native_chargerstates,
+                listenerentity=self.chargertype.charger.entities.chargerentity
+            )
+            resultdict[self.chargerobject.entity] = self.chargerobject.is_initialized
+        else:
+            self.chargerobject = None
 
         self.carpowersensor = CarPowerSensor(
             data_type=int,
@@ -88,8 +94,9 @@ class IHubSensors:
 
     def init_hub_values(self):
         """Initialize values from Home Assistant on the set objects"""
-        self.chargerobject.value = self.state_machine.states.get(self.chargerobject.entity).state if self.state_machine.states.get(
-            self.chargerobject.entity) is not None else 0
+        if self.chargerobject is not None:
+            self.chargerobject.value = self.state_machine.states.get(self.chargerobject.entity).state if self.state_machine.states.get(
+                self.chargerobject.entity) is not None else 0
         self.chargerobject_switch.value = self.state_machine.states.get(
             self.chargerobject_switch.entity).state if self.state_machine.states.get(
             self.chargerobject_switch.entity) is not None else ""
@@ -114,10 +121,6 @@ class HubSensorsLite(IHubSensors):
 
 @dataclass
 class HubSensors(IHubSensors):
-    powersensormovingaverage: HubMember = field(init=False)
-    powersensormovingaverage24: HubMember = field(init=False)
-    power: Power = field(init=False)
-
     def setup(
         self,
         state_machine,
