@@ -25,7 +25,7 @@ class CarPowerSensor(HubMember):
     def is_initialized(self) -> bool:
         if self._is_initialized is True:
             return True
-        if isinstance(self.value, (float,int)) and self._hubdata.chargerobject.is_initialized:
+        if isinstance(self.value, (float,int)) and (self._hubdata.chargerobject.is_initialized or self._hubdata.chargerobject is None):
             _LOGGER.debug(f"{CARPOWERSENSOR} has initialized")
             self._is_initialized = True
             return True
