@@ -88,20 +88,20 @@ class PriceAwareHours(Hours):
         return False
 
     def get_average_kwh_price(self):
-        #if self._is_initialized:
-        try:
-            return self._core.get_average_kwh_price()
-        except ZeroDivisionError as e:
-            _LOGGER.warning(e)
-        return 0
+        if self._is_initialized:
+            try:
+                return self._core.get_average_kwh_price()
+            except ZeroDivisionError as e:
+                _LOGGER.warning(e)
+            return 0
 
     def get_total_charge(self):
-        #if self._is_initialized:
-        try:
-            return self._core.get_total_charge(self._hub.sensors.current_peak.value)
-        except ZeroDivisionError as e:
-            _LOGGER.warning(e)
-        return 0
+        if self._is_initialized:
+            try:
+                return self._core.get_total_charge(self._hub.sensors.current_peak.value)
+            except ZeroDivisionError as e:
+                _LOGGER.warning(e)
+            return 0
 
     @staticmethod
     def _set_absolute_top_price(_input) -> float:
