@@ -16,11 +16,12 @@ class Locale_Type:
     observed_peak: str
     charged_peak: str
     query_model: LocaleQuery
+    price: LocalePrice = None
     free_charge_pattern: FreeChargePattern = None
     peak_cycle: str = HOURLY
     #converted: bool = False #transition key to remove sql-dependency
     is_quarterly: bool = field(init=False, repr=False)
-    price: LocalePrice = field(init=False)
+    
 
     def free_charge(self, mockdt: datetime=datetime.min) -> bool:
         if self.free_charge_pattern is None:
